@@ -5,21 +5,42 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
+#include "config-knetwalk.h"
+
 #include "mainwindow.h"
 #include "knetwalk_version.h"
 
 #include <KAboutData>
 #include <KCrash>
 #include <KLocalizedString>
+#if HAVE_KDBUSADDONS
 #include <KDBusService>
+#endif
+#define HAVE_KICONTHEME __has_include(<KIconTheme>)
+#if HAVE_KICONTHEME
+#include <KIconTheme>
+#endif
 
+#define HAVE_STYLE_MANAGER __has_include(<KStyleManager>)
+#if HAVE_STYLE_MANAGER
+#include <KStyleManager>
+#endif
 #include <QApplication>
 #include <QCommandLineParser>
 
 int main(int argc, char ** argv)
 {
+#if HAVE_KICONTHEME
+    KIconTheme::initTheme();
+#endif
     QApplication app(argc, argv);
-
+#if HAVE_STYLE_MANAGER
+    KStyleManager::initStyle();
+#else // !HAVE_STYLE_MANAGER
+#if defined(Q_OS_MACOS) || defined(Q_OS_WIN)
+    QApplication::setStyle(QStringLiteral("breeze"));
+#endif // defined(Q_OS_MACOS) || defined(Q_OS_WIN)
+#endif // HAVE_STYLE_MANAGER
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("knetwalk"));
 
     KAboutData about(QStringLiteral("knetwalk"), i18n("KNetWalk"),
@@ -59,7 +80,9 @@ int main(int argc, char ** argv)
     about.processCommandLine(&parser);
 
     KCrash::initialize();
+#if HAVE_KDBUSADDONS
     KDBusService service;
+#endif
  
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("knetwalk")));
 
